library wolfizutils;

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart';
import 'package:connectivity/connectivity.dart';
import 'package:dio/dio.dart';
import 'package:wolfizutils/models/wolfiz_variables.dart';

part './widgets/my_text_widget.dart';

part './widgets/png_image_button.dart';

part './widgets/svg_image_button.dart';

part './widgets/gradient_button_LtR.dart';

part './widgets/gradient_button_TtB.dart';

part './widgets/width_box.dart';

part './widgets/height_box.dart';
part './widgets/square_box.dart';

class WolfizUtils {
  var _wolfizVariables = Get.put(
    WolfizVariables(hasInternet: true.obs),
  );

  Future<void> checkInternetConnection() async {
    await _pingGoogle();
    Connectivity()
        .onConnectivityChanged
        .listen((ConnectivityResult result) async {
      if (result == ConnectivityResult.none) {
        _wolfizVariables.hasInternet.value = false;
      } else {
        await _pingGoogle();
      }
    });
  }

  Future<void> _pingGoogle() async {
    try {
      final pingResponse =
          await Dio().get("https://google.com").catchError((onError) {
        print(onError);
      });
      print(pingResponse);
      _wolfizVariables.hasInternet.value = true;
    } catch (e) {
      _wolfizVariables.hasInternet.value = false;
    }
  }
}

extension WolfizUtilExtension on Widget {
  Widget ifNoInternet({Widget child = const SizedBox()}) {
    try {
      final wolfizVariables = Get.find<WolfizVariables>();
      return Obx(
        () => wolfizVariables.hasInternet.value ? this : child,
      );
    } catch (e) {
      throw "You might not have checkInternetConnection on init function of base controller";
    }
  }
}
